#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-swagger
version:              1.2.1
visibility:           public
id:                   servant-swagger-1.2.1-FYFVVfR8TTY1rq96hFWluI
key:                  servant-swagger-1.2.1-FYFVVfR8TTY1rq96hFWluI
license:              BSD-3-Clause
copyright:            (c) 2015-2018, Servant contributors
maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:
    https://github.com/haskell-servant/servant/tree/master/servant-swagger#readme

synopsis:
    Generate a Swagger/OpenAPI/OAS 2.0 specification for your servant API.

description:
    Swagger is a project used to describe and document RESTful APIs. The core of the
    project is the [OpenAPI Specification (OAS)](https://swagger.io/docs/specification/about/).
    This library implements v2.0 of the spec. Unlike Servant it is language-agnostic and thus is
    quite popular among developers in different languages. It has also existed for a longer time
    and has more helpful tooling.

    This package provides means to generate a Swagger/OAS specification for a Servant API
    and also to partially test whether an API conforms with its specification.

    Generated Swagger specification then can be used for many things such as

    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);

    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);

    * and [many others](http://swagger.io/open-source-integrations/).

category:             Web, Servant, Swagger
abi:                  9ba6969ed7a88bfdde80a2f22ea83784
exposed:              True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Orphans Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel

import-dirs:          /usr/lib/ghc-9.6.6/site-local/servant-swagger-1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/servant-swagger-1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/servant-swagger-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-swagger
hs-libraries:         HSservant-swagger-1.2.1-FYFVVfR8TTY1rq96hFWluI
depends:
    QuickCheck-2.15.0.1-FUcewYgFPTwGfyjnEpPlTz
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o
    aeson-pretty-0.8.11-BqVhnnBaupkIjWZ0yhugs4 base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4 bytestring-0.11.5.3
    hspec-2.11.7-7U6fx3dsaNQ7EcGdmqSFJ7
    http-media-0.8.1.1-9xp3eR42oHREfldBp8wJZO
    insert-ordered-containers-0.2.5.3-JUL2fOdYB7w3qE0lAj0D0h
    lens-5.3.4-FoS34BQg8yPHQoAczDydbc
    servant-0.20.3.0-HxJc4HNE5VN5ggSNE5tRj0
    singleton-bool-0.1.8-A0yWmdGcL2cJ9LcX2VI9CL
    swagger2-2.8.10-F1dPGQdr6a2GucYPoMutM7 text-2.0.2
    unordered-containers-0.2.20.1-4LGdNZVNGNC9SVCFAuU8Mp

haddock-interfaces:
    /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock

haddock-html:         /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

